FlexHttpRequest class

Represents an HTTP request with cancellation support.

Constructors

FlexHttpRequest(HttpClientRequest request)

Properties

hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
Whether the request has been cancelled.
no setter
request HttpClientRequest
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Cancels the request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited