FlexInterceptor class abstract

Abstract base class for intercepting HTTP requests and responses.

Extend this to add custom behavior like logging or authentication.

Implementers

Constructors

FlexInterceptor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRequest(FlexHttpRequest request) Future<void>
Called before a request is sent.
onResponse(FlexResponse response) Future<void>
Called after a response is received.
onStreamResponse(FlexStreamResponse response) Future<void>
Called for each chunk of a streamed response.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited