FlexResponse<T> class

Represents an HTTP response with decoded body support.

T is the type of the decoded body.

Constructors

FlexResponse({required int statusCode, required String body, required HttpHeaders headers, required String method, T decoder(dynamic)?})

Properties

body String
final
hashCode int
The hash code for this object.
no setterinherited
headers HttpHeaders
final
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

decodedBody() → T
Decodes the response body into type T.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited