FlexStreamResponse<T> class
Represents a streamed HTTP response chunk.
Constructors
- FlexStreamResponse({required int statusCode, required T data, required HttpHeaders headers})
Properties
- data → T
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → HttpHeaders
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited